<?php
/**
 * An interface for socket discovery
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface DiscoverableSocket extends DiscoverableRecipient {
	/**
	 * Tries to discover the right socket for given package data and returns a
	 * matching socket resource.
	 *
	 * @param	$packageData		Raw package data array
	 * @param	$connectionType		Type of connection, can be 'incoming' or 'outgoing', *NEVER* 'server'!
	 * @return	$socketResource		A valid socket resource
	 * @throws	NoListGroupException	If the procol group is not found in peer list
	 * @throws	NullPointerException	If listenerInstance is NULL
	 */
	function discoverSocket (array $packageData, $connectionType);

	/**
	 * Tries to dicover the right listener instance
	 *
	 * @param	$protocolInstance	An instance of a HandleableProtocol class
	 * @param	$packageData		Raw package data
	 * @return	$listenerInstance	An instance of a Listenable instance or null
	 */
	function discoverListenerInstance (HandleableProtocol $protocolInstance, array $packageData);
}

// [EOF]
?>
