<?php
/**
 * A PackageRecipient discovery class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class BaseRecipientDiscovery extends BaseNodeDiscovery implements DiscoverableRecipient {
	/**
	 * Protected constructor
	 *
	 * @param	$className	Real class name
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);

		/*
		 * Get recipients list instance and set it here for all discovery
		 * implementations.
		 */
		$listInstance = RecipientListFactory::createRecipientListInstance();
		$this->setListInstance($listInstance);
	}

	/**
	 * "Getter" for recipient iterator
	 *
	 * @return$iteratorInstance An instance of a Iterateable object
	 */
	public final function getIterator () {
		// Get iterator from it
		$iteratorInstance = $this->getListInstance()->getIterator();

		// Return it
		return $iteratorInstance;
	}

	/**
	 * Clears all recipients for e.g. another package to deliver. This method
	 * simply clears the inner list instance.
	 *
	 * @return	void
	 */
	public final function clearRecipients () {
		// Clear the list
		$this->getListInstance()->clearList();
	}

	/**
	 * Checks whether the recipient list is empty
	 *
	 * @return	$isEmpty	Whether the recipient list is empty
	 */
	public final function isRecipientListEmpty () {
		// Check it ...
		$isEmpty = ($this->getListInstance()->count() == 0);

		// Return it
		return $isEmpty;
	}
}

// [EOF]
?>
