<?php
/**
 * A PhpRequirements filter for miners
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2014 Miner Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class MinerPhpRequirementsFilter extends BaseMinerFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createMinerPhpRequirementsFilter () {
		// Get a new instance
		$filterInstance = new MinerPhpRequirementsFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If a required PHP function is not available
	 * @todo	Add more test and try to add an extra message to the thrown exception
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// By default, the requirement check is passed and zero checks are failed
		$checkPassed = TRUE;
		$checksFailed = 0;

		// Socket support is essential...
		if (!function_exists('socket_create')) {
			// Test failed
			$checkPassed = FALSE;
			$checksFailed++;
		} // END -if

		// If scrypt() is not found (ext-scrypt) then the "Hubcoins reward" is not working
		if ((extension_loaded('scrypt')) && (is_callable('scrypt'))) {
			// Mark it as working
			self::createDebugInstance(__CLASS__)->debugOutput('FILTER[' . __METHOD__ . ':' . __LINE__ . '] ext-scrypt and a callable scrypt() function found. "Hubcoin reward" feature enabled.');
			$this->getConfigInstance()->setConfigEntry('extension_scrypt_loaded', TRUE);
		} else {
			// Not working (not all have ext-scrypt installed
			self::createDebugInstance(__CLASS__)->debugOutput('FILTER[' . __METHOD__ . ':' . __LINE__ . '] ext-scrypt not found or scrypt() function not found. "Hubcoin reward" feature disabled.');
		}

		// Are all tests passed?
		if ($checkPassed === FALSE) {
			// Throw an exception
			throw new FilterChainException($this, self::FILTER_CHAIN_INTERCEPTED);
		} // END - if
	}
}

// [EOF]
?>
